# Weather Lookup

Lookup the live weather data to any city!

## Valid Queries

- City name 
- State name
- Zipcode


## Installation

``` Bash
pip install WeatherLookup
```

## Usage 

```Python
import WeatherLookup

DubaiWeather = WeatherLookup.temperature('Dubai')
print(DubaiWeather)

```

```Python
import WeatherLookup

DubaiCondition = WeatherLookup.condition('Dubai')
print(DubaiCondition)

```